@@ -11,6 +11,6 @@ __author__ = 'SuprSend Developers'
 __credits__ = 'SuprSend'
 
 from .sdkinstance import Suprsend           # noqa
-from .batch_response import BatchResponse   # noqa
+from .bulk_response import BulkResponse     # noqa
 from .event import Event                    # noqa
 from .workflow import Workflow              # noqa
